
input[type=checkbox] {
  /* these margins are for NavQuirks, we need a Standard ua.css */  
  margin-left:   3px;   
  margin-right:  5px;  
  margin-top:    3px; 
  margin-bottom: 4px;
  border: 1px outset rgb(153, 153, 153);
  width:11px;
  height:11px;
  background-color:rgb(204, 204, 204);
  color:black;
/*  -moz-border-radius:1px; */
}

input[type=radio] {
  /* these margins are for NavQuirks, we need a Standard ua.css */  
  margin-left:   3px;   
  margin-right:  5px;  
  margin-top:    3px; 
  margin-bottom: 3px; 
  border: 2px outset rgb(204, 204, 204);
  background-color:rgb(204, 204, 204);
  color:black;
  width:12px;
  height:12px;
  -moz-border-radius:6px;
}

input[type=radio]:active {
  background-color:white;
  border: 2px inset rgb(204, 204, 204);
}

input[type=radio]:hover {
  border : 2px solid black;
}

:-moz-radio {
  background-color:black;
  width:6px;
  height:6px;
  left:6px;
  top:6px;
  -moz-border-radius:3px;
}

input[type="button"] { 
  border: 2px outset rgb(156, 154, 156);
  background-color: rgb(206, 207, 206);
  color:black; 

  padding: 1px;
}

input[type="button"]:active {
  border-style: inset;

  padding-left: 2px;
  padding-right: 0px;
  padding-top: 2px;
  padding-bottom: 0px;
}

input[type="button"]:active:-moz-outline {
   border : 1px solid black;
}

input[type="button"]:hover:-moz-outline {
   border : 1px solid black;
}

input[type="button"][disabled] {
   border-style: solid;
}

input[type="button"][disabled]:active {
  padding: 1px;
}

input[type="button"]:-moz-focus-inner {
   padding-left  : 2px;
   padding-right : 2px;
   padding-top   : 1px;
   padding-bottom: 1px;
   margin: 0px;
}

input[type="button"]:focus:-moz-focus-inner {
   padding-left  : 1px;
   padding-right : 1px;
   padding-top   : 0px;
   padding-bottom: 0px;
 
   margin: 0px;
   border : 1px dotted black;
}


button { 
  display: inline;
  vertical-align: bottom;
  cursor: default;

  border: 2px outset rgb(156, 154, 156);
  background-color: rgb(206, 207, 206);
  color:black; 

  padding: 1px;
}

button:active {
  border-style: inset;

  padding-left: 2px;
  padding-right: 0px;
  padding-top: 2px;
  padding-bottom: 0px;
}

button:hover {
}

button:active:-moz-outline {
   border : 1px solid black;
}

button:hover:-moz-outline {
   border : 1px solid black;
}

button[disabled] {
   border-style: solid;
}

button[disabled]:active {
  padding: 1px;
}

button:-moz-focus-inner {
   padding-left  : 2px;
   padding-right : 2px;
   padding-top   : 1px;
   padding-bottom: 1px;
   margin: 0px;
}

button:focus:-moz-focus-inner {
   padding-left  : 1px;
   padding-right : 1px;
   padding-top   : 0px;
   padding-bottom: 0px;
 
   margin: 0px;
   border : 1px dotted black;
}

:-moz-dropdown-list {
  border-color:black;
  -moz-border-radius:4px;
  background-color:rgb(200, 200, 200);
}

/* Combo box style */
select, select[size="1"] {
  vertical-align: bottom;
  border: none;
  background-color:rgb(204, 204, 204);  
  color:black;
  white-space:nowrap;
  text-align: left; 
}


/* combobox button */
select input[type=button] {
  border: outset 1px rgb(204, 204, 204);
  background-image:url("arrow.gif");
  background-repeat:no-repeat;
  background-position:center;
  width:12px;
  height:12px;
  -moz-border-radius:0px;
}

/* combobox display area */
select input#-moz-display {
  border: inset 1px rgb(204, 204, 204);
  background-color: white;
  background-image: none;
  -moz-border-radius:0px;
  padding-left: 0px;
  padding-right: 0px;
  padding-top: 0px;
  padding-bottom: 0px;
}

/* combbox display area - active */
select input#-moz-display:active {
  border: inset 1px rgb(204, 204, 204);
  background-color:white;
  background-image: none;
  -moz-border-radius:0px;
  padding-left: 0px;
  padding-right: 0px;
  padding-top: 0px;
  padding-bottom: 0px;
  background-color:white;
}

option {
  display:block;
  padding-left:3px;
  padding-right:3px;
}

/* Combobox item style */
select option[_moz-option-selected] {
 color:black;
 background-color:white; 
}

/* List box item selected style */
select[size] option[_moz-option-selected] {
 color:white;
 background-color:rgb(51,51,102); 
}

select[size="1"] option[_moz-option-selected] {
  color:black;
  background-color:white;
}

option.selectedfocus {
  border:   1px dotted white;
  background-color: rgb(0,0,128);
  color: rgb(255,255,255);
}

optgroup {
  font-style:italic;
  font-weight:bold;
}

optgroup > option {
  padding-left:20px;
  font-style:normal;
  font-weight:normal;
}

textarea {
  vertical-align: bottom;
  border: 2px inset #c0c0c0;
  background-color:white;
  color:black;
}